#[non_exhaustive]pub enum Error {
WinError(u32),
BusNotFound,
BusAccessFailed(u32),
BusVersionMismatch,
NoFreeSlot,
AlreadyConnected,
NotPluggedIn,
TargetNotReady,
UserIndexOutOfRange,
OperationAborted,
}Expand description
ViGEm client errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
WinError(u32)
There was an unexpected windows error.
See System Error Codes for more information.
BusNotFound
The ViGEmBus Driver is not installed.
It can be installed from the ViGEmBus repository.
BusAccessFailed(u32)
ViGEmBus was found, but accessing it returned an error.
BusVersionMismatch
ViGEmBus was found, but it did not accept this client’s version.
NoFreeSlot
There was no more room to allocate new targets.
AlreadyConnected
The target is already connected.
It is an error to try to plugin an already connected target.
NotPluggedIn
The target is not plugged in.
TargetNotReady
The target is not ready.
After creating the desired controller, wait some time before the target is ready to accept updates. This error is returned if a target is updated before it is ready.
UserIndexOutOfRange
The user index is out of range.
In XInput the user index should be between 0 and 4 exclusive.
OperationAborted
The operation was aborted.