Enum vigem_client::Error[][src]

pub enum Error {
    WinError(u32),
    BusNotFound,
    BusAccessFailed(u32),
    BusVersionMismatch,
    NoFreeSlot,
    AlreadyConnected,
    NotPluggedIn,
    TargetNotReady,
    UserIndexOutOfRange,
}
ViGEm client errors.

Variants

WinError

There was an unexpected windows error.

See System Error Codes for more information.

Tuple Fields of WinError

0: u32
BusNotFound

The ViGEmBus Driver is not installed.

It can be installed from the ViGEmBus repository.

BusAccessFailed

ViGEmBus was found, but accessing it returned an error.

Tuple Fields of BusAccessFailed

0: u32
BusVersionMismatch

ViGEmBus was found, but it did not accept this client’s version.

NoFreeSlot

There was no more room to allocate new targets.

AlreadyConnected

The target is already connected.

It is an error to try to plugin an already connected target.

NotPluggedIn

The target is not plugged in.

TargetNotReady

The target is not ready.

After creating the desired controller, wait some time before the target is ready to accept updates. This error is returned if a target is updated before it is ready.

UserIndexOutOfRange