Enum vigem_client::Error [−][src]
pub enum Error {
WinError(u32),
BusNotFound,
BusAccessFailed(u32),
BusVersionMismatch,
NoFreeSlot,
AlreadyConnected,
NotPluggedIn,
TargetNotReady,
UserIndexOutOfRange,
}Expand description
ViGEm client errors.
Variants
There was an unexpected windows error.
See System Error Codes for more information.
Tuple Fields of WinError
0: u32The ViGEmBus Driver is not installed.
It can be installed from the ViGEmBus repository.
ViGEmBus was found, but accessing it returned an error.
Tuple Fields of BusAccessFailed
0: u32ViGEmBus was found, but it did not accept this client’s version.
There was no more room to allocate new targets.
The target is already connected.
It is an error to try to plugin an already connected target.
The target is not plugged in.
The target is not ready.
After creating the desired controller, wait some time before the target is ready to accept updates. This error is returned if a target is updated before it is ready.